package com.stormtales.notevault.ui.home;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;
import androidx.activity.result.ActivityResult;
import androidx.activity.result.ActivityResultCallback;
import androidx.activity.result.ActivityResultLauncher;
import androidx.activity.result.contract.ActivityResultContracts;
import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import com.google.android.material.floatingactionbutton.FloatingActionButton;
import com.stormtales.notevault.R;
import com.stormtales.notevault.databinding.FragmentHomeBinding;
import com.stormtales.notevault.ui.songeditor.SongEditorDialog;

public class HomeFragment extends Fragment {

    private FragmentHomeBinding binding;
    private static final int PICK_FILE_REQUEST_CODE = 1;

    public View onCreateView(@NonNull LayoutInflater inflater,
                             ViewGroup container, Bundle savedInstanceState) {
        HomeViewModel homeViewModel =
                new ViewModelProvider(this).get(HomeViewModel.class);

        binding = FragmentHomeBinding.inflate(inflater, container, false);
        View root = binding.getRoot();
        ActivityResultLauncher<Intent> launcher = registerForActivityResult(
                new ActivityResultContracts.StartActivityForResult(),
                activityResult -> {
                    getActivity();
                    if(activityResult.getResultCode() == Activity.RESULT_OK && activityResult.getData() != null) {
                        if(activityResult.getData().getClipData() != null) {
                            int fileNumber = activityResult.getData().getClipData().getItemCount();
                            Uri[] files = new Uri[fileNumber];
                            for(int i = 0; i < fileNumber; i++) {
                                files[i] = activityResult.getData().getClipData().getItemAt(i).getUri();
                                Toast.makeText(requireContext(), "Uri: " + files[i].toString(), Toast.LENGTH_SHORT).show();
                            }
                            handleSelectedNoteSheets(files);
                        } else {
                            Uri uri = activityResult.getData().getData();
                            Toast.makeText(requireContext(), "Uri: " + uri.toString(), Toast.LENGTH_SHORT).show();
                            handleSelectedNoteSheets(uri);
                        }
                    }
                }
        );

        FloatingActionButton importBtn = root.findViewById(R.id.addSongBtn);
        importBtn.setOnClickListener(v -> {
            Intent intent = new Intent(Intent.ACTION_OPEN_DOCUMENT);
            intent.setType("*/*"); // Alle Dateitypen

            String[] mimeTypes = {"application/pdf", "image/png", "image/jpeg"};
            intent.putExtra(Intent.EXTRA_MIME_TYPES, mimeTypes);
            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);

            intent.addCategory(Intent.CATEGORY_OPENABLE);


            launcher.launch(intent);
        });

        final TextView textView = binding.textHome;
        homeViewModel.getText().observe(getViewLifecycleOwner(), textView::setText);
        return root;
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        binding = null;
    }

    private void handleSelectedNoteSheets(Uri... files) {
        SongEditorDialog songEditorDialog = new SongEditorDialog();
        songEditorDialog.setNoteSheetFiles(files);
        songEditorDialog.show(getParentFragmentManager(), "songEditorDialog");
    }
}